@@ -23,9 +23,10 @@ class DBaaSRouting:
             except KeyboardInterrupt:
                 Py_version_manager.py_print(" ")
             except Exception as e:
-                            e=str(e)
-                            if(e=="'data'" or e=="'code'"):
+                            if(str(e)=="'data'" or str(e)=="'code'"):
                                 Py_version_manager.py_print("Oops!! Your access credentials seems to have expired")
+                            else:
+                                raise e
 
         elif self.arguments.dbaas_commands == 'list' or self.arguments.dbaas_commands == 'ls':
             if "alias=" in self.arguments.alias:
@@ -38,9 +39,10 @@ class DBaaSRouting:
             except KeyboardInterrupt:
                 Py_version_manager.py_print(" ")
             except Exception as e:
-                            e=str(e)
-                            if(e=="'data'" or e=="'code'"):
+                            if(str(e)=="'data'" or str(e)=="'code'"):
                                 Py_version_manager.py_print("Oops!! Your access credentials seems to have expired")
+                            else:
+                                raise e
 
         elif self.arguments.dbaas_commands == 'delete':
             if "alias=" in self.arguments.alias:
@@ -53,7 +55,8 @@ class DBaaSRouting:
             except KeyboardInterrupt:
                 Py_version_manager.py_print(" ")
             except Exception as e:
-                            e=str(e)
-                            if(e=="'data'" or e=="'code'"):
+                            if(str(e)=="'data'" or str(e)=="'code'"):
                                 Py_version_manager.py_print("Oops!! Your access credentials seems to have expired")
+                            else:
+                                raise e
             
